==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Widgets/CommandLine/ts/CommandLine_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>CommandLine</name>
    <message>
        <location filename="../CommandLine.js" line="+30"/>
        <source>Widgets</source>
        <translation>Gradniki</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+46"/>
        <location filename="../CommandLine.ui" line="+20"/>
        <source>Command Line</source>
        <translation>Ukazna vrstica</translation>
    </message>
    <message>
        <location line="-16"/>
        <source>&amp;Command Line</source>
        <translation>&amp;Ukazna vrstica</translation>
    </message>
    <message>
        <location line="+167"/>
        <source>Invalid value:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Invalid coordinate or distance &apos;%1&apos;.</source>
        <translation>Neveljavna koordinata ali razdalja &apos;%1&apos;.</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Unknown command or invalid coordinate or value: &apos;%1&apos;</source>
        <translation>Neznan ukaz ali neveljavna vrednost ali koordinata: &apos;%1&apos;</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Numbers may be entered as: &apos;%1&apos;</source>
        <translation>Števila se lahko vnesejo kot: &apos;%1&apos;</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Coordinates may be entered as: &apos;%1&apos; (absolute) or &apos;%2&apos; (relative) or &apos;%3&apos; (polar) or &apos;%4&apos; (relative polar)</source>
        <translation>Koordinate se lahko vnesejo kot: &apos;%1&apos; (absolutno) ali &apos;%2&apos; (relativno) ali &apos;%3&apos; (polarno) ali &apos;%4&apos; (relativno polarno)</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>You may change the number / coordinate format in the application preferences.</source>
        <translation>Fromat zapisa števil / koordintat lahko spremenite v nastavitvah aplikacije.</translation>
    </message>
    <message>
        <location line="+64"/>
        <source>Transaction failed. Please check for block recursions and locked or invisible layers or blocks.</source>
        <translation>Prenos je spodletel. Preverite za rekurzije blokov ter zaklenjenih ali nevidnih slovjev oz blokov.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Warning</source>
        <translation>Opozorilo</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Expression</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Coordinate</source>
        <translation>Koordinate</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Command</source>
        <translation>Ukaz</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Command:</source>
        <translation>Ukaz:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>: </source>
        <translation>: </translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>History Size:</source>
        <translation>Število vrstic zgodovine:</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Show warnings as dialog</source>
        <translation>Prikaži opozorila kot dialog</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Show information as dialog</source>
        <translation>Prikaži informacije kot dialog</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Widgets/CommandLine/ts/CommandLine_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>CommandLine</name>
    <message>
        <location filename="../CommandLine.js" line="+30"/>
        <source>Widgets</source>
        <translation>Gradniki</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+46"/>
        <location filename="../CommandLine.ui" line="+20"/>
        <source>Command Line</source>
        <translation>Ukazna vrstica</translation>
    </message>
    <message>
        <location line="-16"/>
        <source>&amp;Command Line</source>
        <translation>&amp;Ukazna vrstica</translation>
    </message>
    <message>
        <location line="+188"/>
        <source>Invalid value:</source>
        <translation>Neveljavna vrednost:</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Invalid coordinate or distance &apos;%1&apos;.</source>
        <translation>Neveljavna koordinata ali razdalja &apos;%1&apos;.</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Unknown command or invalid coordinate or value: &apos;%1&apos;</source>
        <translation>Neznan ukaz ali neveljavna vrednost ali koordinata: &apos;%1&apos;</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Numbers may be entered as: &apos;%1&apos;</source>
        <translation>Števila se lahko vnesejo kot: &apos;%1&apos;</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Coordinates may be entered as: &apos;%1&apos; (absolute) or &apos;%2&apos; (relative) or &apos;%3&apos; (polar) or &apos;%4&apos; (relative polar)</source>
        <translation>Koordinate se lahko vnesejo kot: &apos;%1&apos; (absolutno) ali &apos;%2&apos; (relativno) ali &apos;%3&apos; (polarno) ali &apos;%4&apos; (relativno polarno)</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>You may change the number / coordinate format in the application preferences.</source>
        <translation>Fromat zapisa števil / koordintat lahko spremenite v nastavitvah aplikacije.</translation>
    </message>
    <message>
        <location line="+68"/>
        <source>Transaction failed. Please check for block recursions and locked or invisible layers or blocks.</source>
        <translation>Prenos je spodletel. Preverite za rekurzije blokov ter zaklenjenih ali nevidnih slovjev oz blokov.</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Warning</source>
        <translation>Opozorilo</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Expression</source>
        <translation>Izraz</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Coordinate</source>
        <translation>Koordinate</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Command</source>
        <translation>Ukaz</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Command:</source>
        <translation>Ukaz:</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>: </source>
        <translation>: </translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>History Size:</source>
        <translation>Število vrstic zgodovine:</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Show warnings as dialog</source>
        <translation>Prikaži opozorila kot dialog</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Show information as dialog</source>
        <translation>Prikaži informacije kot dialog</translation>
    </message>
</context>
</TS>
